@@ -23,6 +23,7 @@ import gzip as gz
 import io
 import re
 import shutil
+from datetime import datetime
 from functools import wraps
 from inspect import signature
 from io import BytesIO
@@ -255,6 +256,18 @@ class S3Hook(AwsBaseHook):
 
         return prefixes
 
+    def _list_key_object_filter(
+        self, keys: list, from_datetime: Optional[datetime] = None, to_datetime: Optional[datetime] = None
+    ) -> list:
+        def _is_in_period(input_date: datetime) -> bool:
+            if from_datetime is not None and input_date <= from_datetime:
+                return False
+            if to_datetime is not None and input_date > to_datetime:
+                return False
+            return True
+
+        return [k['Key'] for k in keys if _is_in_period(k['LastModified'])]
+
     @provide_bucket_name
     def list_keys(
         self,
@@ -263,6 +276,10 @@ class S3Hook(AwsBaseHook):
         delimiter: Optional[str] = None,
         page_size: Optional[int] = None,
         max_items: Optional[int] = None,
+        start_after_key: Optional[str] = None,
+        from_datetime: Optional[datetime] = None,
+        to_datetime: Optional[datetime] = None,
+        object_filter: Optional[Callable[..., list]] = None,
     ) -> list:
         """
         Lists keys in a bucket under prefix and not containing delimiter
@@ -272,11 +289,40 @@ class S3Hook(AwsBaseHook):
         :param delimiter: the delimiter marks key hierarchy.
         :param page_size: pagination size
         :param max_items: maximum items to return
+        :param start_after_key: should return only keys greater than this key
+        :param from_datetime: should return only keys with LastModified attr greater than this equal
+            from_datetime
+        :param to_datetime: should return only keys with LastModified attr less than this to_datetime
+        :param object_filter: Function that receives the list of the S3 objects, from_datetime and
+            to_datetime and returns the List of matched key.
+
+        **Example**: Returns the list of S3 object with LastModified attr greater than from_datetime
+             and less than to_datetime:
+
+        .. code-block:: python
+
+            def object_filter(
+                keys: list,
+                from_datetime: Optional[datetime] = None,
+                to_datetime: Optional[datetime] = None,
+            ) -> list:
+                def _is_in_period(input_date: datetime) -> bool:
+                    if from_datetime is not None and input_date < from_datetime:
+                        return False
+
+                    if to_datetime is not None and input_date > to_datetime:
+                        return False
+                    return True
+
+                return [k["Key"] for k in keys if _is_in_period(k["LastModified"])]
+
         :return: a list of matched keys
         :rtype: list
         """
         prefix = prefix or ''
         delimiter = delimiter or ''
+        start_after_key = start_after_key or ''
+        self.object_filter_usr = object_filter
         config = {
             'PageSize': page_size,
             'MaxItems': max_items,
@@ -284,16 +330,23 @@ class S3Hook(AwsBaseHook):
 
         paginator = self.get_conn().get_paginator('list_objects_v2')
         response = paginator.paginate(
-            Bucket=bucket_name, Prefix=prefix, Delimiter=delimiter, PaginationConfig=config
+            Bucket=bucket_name,
+            Prefix=prefix,
+            Delimiter=delimiter,
+            PaginationConfig=config,
+            StartAfter=start_after_key,
         )
 
         keys = []
         for page in response:
             if 'Contents' in page:
                 for k in page['Contents']:
-                    keys.append(k['Key'])
+                    keys.append(k)
 
-        return keys
+        if self.object_filter_usr is not None:
+            return self.object_filter_usr(keys, from_datetime, to_datetime)
+
+        return self._list_key_object_filter(keys, from_datetime, to_datetime)
 
     @provide_bucket_name
     @unify_bucket_name_and_key
