@@ -18,6 +18,7 @@
 import re
 import sys
 import time
+import warnings
 from collections import deque
 from datetime import datetime, timedelta
 from logging import Logger
@@ -29,7 +30,7 @@ from botocore.waiter import Waiter
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator, XCom
-from airflow.providers.amazon.aws.exceptions import ECSOperatorError
+from airflow.providers.amazon.aws.exceptions import EcsOperatorError, EcsTaskFailToStart
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 from airflow.providers.amazon.aws.hooks.logs import AwsLogsHook
 from airflow.typing_compat import Protocol, runtime_checkable
@@ -38,7 +39,7 @@ from airflow.utils.session import provide_session
 
 def should_retry(exception: Exception):
     """Check if exception is related to ECS resource quota (CPU, MEM)."""
-    if isinstance(exception, ECSOperatorError):
+    if isinstance(exception, EcsOperatorError):
         return any(
             quota_reason in failure['reason']
             for quota_reason in ['RESOURCE:MEMORY', 'RESOURCE:CPU']
@@ -47,11 +48,21 @@ def should_retry(exception: Exception):
     return False
 
 
+def should_retry_eni(exception: Exception):
+    """Check if exception is related to ENI (Elastic Network Interfaces)."""
+    if isinstance(exception, EcsTaskFailToStart):
+        return any(
+            eni_reason in exception.message
+            for eni_reason in ['network interface provisioning', 'ResourceInitializationError']
+        )
+    return False
+
+
 @runtime_checkable
-class ECSProtocol(Protocol):
+class EcsProtocol(Protocol):
     """
     A structured Protocol for ``boto3.client('ecs')``. This is used for type hints on
-    :py:meth:`.ECSOperator.client`.
+    :py:meth:`.EcsOperator.client`.
 
     .. seealso::
 
@@ -84,7 +95,7 @@ class ECSProtocol(Protocol):
         ...
 
 
-class ECSTaskLogFetcher(Thread):
+class EcsTaskLogFetcher(Thread):
     """
     Fetches Cloudwatch log events with specific interval as a thread
     and sends the log events to the info channel of the provided logger.
@@ -114,11 +125,11 @@ class ECSTaskLogFetcher(Thread):
     def run(self) -> None:
         logs_to_skip = 0
         while not self.is_stopped():
+            time.sleep(self.fetch_interval.total_seconds())
             log_events = self._get_log_events(logs_to_skip)
             for log_event in log_events:
                 self.logger.info(self._event_to_str(log_event))
                 logs_to_skip += 1
-            time.sleep(self.fetch_interval.total_seconds())
 
     def _get_log_events(self, skip: int = 0) -> Generator:
         try:
@@ -151,77 +162,57 @@ class ECSTaskLogFetcher(Thread):
         self._event.set()
 
 
-class ECSOperator(BaseOperator):
+class EcsOperator(BaseOperator):
     """
     Execute a task on AWS ECS (Elastic Container Service)
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
-        :ref:`howto/operator:ECSOperator`
+        :ref:`howto/operator:EcsOperator`
 
     :param task_definition: the task definition name on Elastic Container Service
-    :type task_definition: str
     :param cluster: the cluster name on Elastic Container Service
-    :type cluster: str
     :param overrides: the same parameter that boto3 will receive (templated):
         https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ecs.html#ECS.Client.run_task
-    :type overrides: dict
     :param aws_conn_id: connection id of AWS credentials / region name. If None,
         credential boto3 strategy will be used
         (http://boto3.readthedocs.io/en/latest/guide/configuration.html).
-    :type aws_conn_id: str
     :param region_name: region name to use in AWS Hook.
         Override the region_name in connection (if provided)
-    :type region_name: str
-    :param launch_type: the launch type on which to run your task ('EC2' or 'FARGATE')
-    :type launch_type: str
+    :param launch_type: the launch type on which to run your task ('EC2', 'EXTERNAL', or 'FARGATE')
     :param capacity_provider_strategy: the capacity provider strategy to use for the task.
         When capacity_provider_strategy is specified, the launch_type parameter is omitted.
         If no capacity_provider_strategy or launch_type is specified,
         the default capacity provider strategy for the cluster is used.
-    :type capacity_provider_strategy: list
     :param group: the name of the task group associated with the task
-    :type group: str
     :param placement_constraints: an array of placement constraint objects to use for
         the task
-    :type placement_constraints: list
     :param placement_strategy: an array of placement strategy objects to use for
         the task
-    :type placement_strategy: list
     :param platform_version: the platform version on which your task is running
-    :type platform_version: str
     :param network_configuration: the network configuration for the task
-    :type network_configuration: dict
     :param tags: a dictionary of tags in the form of {'tagKey': 'tagValue'}.
-    :type tags: dict
     :param awslogs_group: the CloudWatch group where your ECS container logs are stored.
         Only required if you want logs to be shown in the Airflow UI after your job has
         finished.
-    :type awslogs_group: str
     :param awslogs_region: the region in which your CloudWatch logs are stored.
         If None, this is the same as the `region_name` parameter. If that is also None,
         this is the default AWS region based on your connection settings.
-    :type awslogs_region: str
     :param awslogs_stream_prefix: the stream prefix that is used for the CloudWatch logs.
         This is usually based on some custom name combined with the name of the container.
         Only required if you want logs to be shown in the Airflow UI after your job has
         finished.
-    :type awslogs_stream_prefix: str
     :param awslogs_fetch_interval: the interval that the ECS task log fetcher should wait
         in between each Cloudwatch logs fetches.
-    :type awslogs_fetch_interval: timedelta
     :param quota_retry: Config if and how to retry the launch of a new ECS task, to handle
         transient errors.
-    :type quota_retry: dict
     :param reattach: If set to True, will check if the task previously launched by the task_instance
         is already running. If so, the operator will attach to it instead of starting a new task.
         This is to avoid relaunching a new task when the connection drops between Airflow and ECS while
         the task is running (when the Airflow worker is restarted for example).
-    :type reattach: bool
     :param number_logs_exception: Number of lines from the last Cloudwatch logs to return in the
         AirflowException if an ECS task is stopped (to receive Airflow alerts with the logs of what
         failed in the code running in ECS).
-    :type number_logs_exception: int
     """
 
     ui_color = '#f0ede4'
@@ -289,23 +280,40 @@ class ECSOperator(BaseOperator):
             self.awslogs_region = region_name
 
         self.hook: Optional[AwsBaseHook] = None
-        self.client: Optional[ECSProtocol] = None
+        self.client: Optional[EcsProtocol] = None
         self.arn: Optional[str] = None
         self.retry_args = quota_retry
-        self.task_log_fetcher: Optional[ECSTaskLogFetcher] = None
+        self.task_log_fetcher: Optional[EcsTaskLogFetcher] = None
 
     @provide_session
     def execute(self, context, session=None):
         self.log.info(
             'Running ECS Task - Task definition: %s - on cluster %s', self.task_definition, self.cluster
         )
-        self.log.info('ECSOperator overrides: %s', self.overrides)
+        self.log.info('EcsOperator overrides: %s', self.overrides)
 
         self.client = self.get_hook().get_conn()
 
         if self.reattach:
             self._try_reattach_task(context)
 
+        self._start_wait_check_task(context)
+
+        self.log.info('ECS Task has been successfully executed')
+
+        if self.reattach:
+            # Clear the XCom value storing the ECS task ARN if the task has completed
+            # as we can't reattach it anymore
+            self._xcom_del(session, self.REATTACH_XCOM_TASK_ID_TEMPLATE.format(task_id=self.task_id))
+
+        if self.do_xcom_push and self.task_log_fetcher:
+            return self.task_log_fetcher.get_last_log_message()
+
+        return None
+
+    @AwsBaseHook.retry(should_retry_eni)
+    def _start_wait_check_task(self, context):
+
         if not self.arn:
             self._start_task(context)
 
@@ -325,18 +333,6 @@ class ECSOperator(BaseOperator):
 
         self._check_success_task()
 
-        self.log.info('ECS Task has been successfully executed')
-
-        if self.reattach:
-            # Clear the XCom value storing the ECS task ARN if the task has completed
-            # as we can't reattach it anymore
-            self._xcom_del(session, self.REATTACH_XCOM_TASK_ID_TEMPLATE.format(task_id=self.task_id))
-
-        if self.do_xcom_push and self.task_log_fetcher:
-            return self.task_log_fetcher.get_last_log_message()
-
-        return None
-
     def _xcom_del(self, session, task_id):
         session.query(XCom).filter(XCom.dag_id == self.dag_id, XCom.task_id == task_id).delete()
 
@@ -371,7 +367,7 @@ class ECSOperator(BaseOperator):
 
         failures = response['failures']
         if len(failures) > 0:
-            raise ECSOperatorError(failures, response)
+            raise EcsOperatorError(failures, response)
         self.log.info('ECS Task started: %s', response)
 
         self.arn = response['tasks'][0]['taskArn']
@@ -430,11 +426,12 @@ class ECSOperator(BaseOperator):
     def _aws_logs_enabled(self):
         return self.awslogs_group and self.awslogs_stream_prefix
 
-    def _get_task_log_fetcher(self) -> ECSTaskLogFetcher:
+    def _get_task_log_fetcher(self) -> EcsTaskLogFetcher:
         if not self.awslogs_group:
             raise ValueError("must specify awslogs_group to fetch task logs")
         log_stream_name = f"{self.awslogs_stream_prefix}/{self.ecs_task_id}"
-        return ECSTaskLogFetcher(
+
+        return EcsTaskLogFetcher(
             aws_conn_id=self.aws_conn_id,
             region_name=self.awslogs_region,
             log_group=self.awslogs_group,
@@ -456,7 +453,12 @@ class ECSOperator(BaseOperator):
         for task in response['tasks']:
 
             if task.get('stopCode', '') == 'TaskFailedToStart':
-                raise AirflowException(f"The task failed to start due to: {task.get('stoppedReason', '')}")
+                # Reset task arn here otherwise the retry run will not start
+                # a new task but keep polling the old dead one
+                # I'm not resetting it for other exceptions here because
+                # EcsTaskFailToStart is the only exception that's being retried at the moment
+                self.arn = None
+                raise EcsTaskFailToStart(f"The task failed to start due to: {task.get('stoppedReason', '')}")
 
             # This is a `stoppedReason` that indicates a task has not
             # successfully finished, but there is no other indication of failure
@@ -509,3 +511,50 @@ class ECSOperator(BaseOperator):
             cluster=self.cluster, task=self.arn, reason='Task killed by the user'
         )
         self.log.info(response)
+
+
+class ECSOperator(EcsOperator):
+    """
+    This operator is deprecated.
+    Please use :class:`airflow.providers.amazon.aws.operators.ecs.EcsOperator`.
+    """
+
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "This operator is deprecated. "
+            "Please use `airflow.providers.amazon.aws.operators.ecs.EcsOperator`.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        super().__init__(*args, **kwargs)
+
+
+class ECSTaskLogFetcher(EcsTaskLogFetcher):
+    """
+    This class is deprecated.
+    Please use :class:`airflow.providers.amazon.aws.operators.ecs.EcsTaskLogFetcher`.
+    """
+
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "This class is deprecated. "
+            "Please use `airflow.providers.amazon.aws.operators.ecs.EcsTaskLogFetcher`.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        super().__init__(*args, **kwargs)
+
+
+class ECSProtocol(EcsProtocol):
+    """
+    This class is deprecated.
+    Please use :class:`airflow.providers.amazon.aws.operators.ecs.EcsProtocol`.
+    """
+
+    def __init__(self):
+        warnings.warn(
+            "This class is deprecated. "
+            "Please use `airflow.providers.amazon.aws.operators.ecs.EcsProtocol`.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
