@@ -16,34 +16,30 @@
 # under the License.
 
 """Publish message to SQS queue"""
+import warnings
 from typing import TYPE_CHECKING, Optional, Sequence
 
 from airflow.models import BaseOperator
-from airflow.providers.amazon.aws.hooks.sqs import SQSHook
+from airflow.providers.amazon.aws.hooks.sqs import SqsHook
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class SQSPublishOperator(BaseOperator):
+class SqsPublishOperator(BaseOperator):
     """
     Publish message to a SQS queue.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
-        :ref:`howto/operator:SQSPublishOperator`
+        :ref:`howto/operator:SqsPublishOperator`
 
     :param sqs_queue: The SQS queue url (templated)
-    :type sqs_queue: str
     :param message_content: The message content (templated)
-    :type message_content: str
     :param message_attributes: additional attributes for the message (default: None)
         For details of the attributes parameter see :py:meth:`botocore.client.SQS.send_message`
-    :type message_attributes: dict
     :param delay_seconds: message delay (templated) (default: 1 second)
-    :type delay_seconds: int
     :param aws_conn_id: AWS connection id (default: aws_default)
-    :type aws_conn_id: str
     """
 
     template_fields: Sequence[str] = ('sqs_queue', 'message_content', 'delay_seconds', 'message_attributes')
@@ -72,12 +68,11 @@ class SQSPublishOperator(BaseOperator):
         Publish the message to SQS queue
 
         :param context: the context object
-        :type context: dict
         :return: dict with information about the message sent
             For details of the returned dict see :py:meth:`botocore.client.SQS.send_message`
         :rtype: dict
         """
-        hook = SQSHook(aws_conn_id=self.aws_conn_id)
+        hook = SqsHook(aws_conn_id=self.aws_conn_id)
 
         result = hook.send_message(
             queue_url=self.sqs_queue,
@@ -89,3 +84,19 @@ class SQSPublishOperator(BaseOperator):
         self.log.info('result is send_message is %s', result)
 
         return result
+
+
+class SQSPublishOperator(SqsPublishOperator):
+    """
+    This operator is deprecated.
+    Please use :class:`airflow.providers.amazon.aws.operators.sqs.SqsPublishOperator`.
+    """
+
+    def __init__(self, *args, **kwargs):
+        warnings.warn(
+            "This operator is deprecated. "
+            "Please use `airflow.providers.amazon.aws.operators.sqs.SqsPublishOperator`.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        super().__init__(*args, **kwargs)
